@@ -201,7 +201,7 @@ class ChainManager:
         the global communicator to split
     """
 
-    def __init__(self, nchains, comm=None):
+    def __init__(self, nchains=1, comm=None):
         global MPI
         MPI = _import_mpi(use_dill=False)
 
@@ -271,8 +271,6 @@ class ChainManager:
         if self.pool is not None:
             self.pool.close()
 
-        return True
-
 
     @property
     def get_rank(self):
@@ -363,4 +361,4 @@ class ChainManager:
         x : Python object
             The input object x in all ranks.
         '''
-        return self.chains_comm.bcast(x, root=root)
\ No newline at end of file
+        return self.chains_comm.bcast(x, root=root)
